==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/mixin/FluidVariantRenderHandlerMixin.java <==
package com.zurrtum.create.client.mixin;

import com.llamalad7.mixinextras.injector.ModifyReturnValue;
import com.llamalad7.mixinextras.sugar.Local;
import com.zurrtum.create.client.AllFluidConfigs;
import com.zurrtum.create.client.infrastructure.fluid.FluidConfig;
import net.fabricmc.fabric.api.transfer.v1.client.fluid.FluidVariantRenderHandler;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidVariant;
import net.minecraft.class_1058;
import net.minecraft.class_3611;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(FluidVariantRenderHandler.class)
public interface FluidVariantRenderHandlerMixin {
    @ModifyReturnValue(method = "getSprites(Lnet/fabricmc/fabric/api/transfer/v1/fluid/FluidVariant;)[Lnet/minecraft/client/texture/Sprite;", at = @At(value = "RETURN", ordinal = 1))
    private class_1058[] getSprites(class_1058[] original, @Local(argsOnly = true) FluidVariant variant) {
        if (original != null) {
            return original;
        }
        class_3611 fluid = variant.getFluid();
        FluidConfig config = AllFluidConfigs.get(fluid);
        if (config != null) {
            return config.toSprite();
        }
        return null;
    }

    @ModifyReturnValue(method = "getColor(Lnet/fabricmc/fabric/api/transfer/v1/fluid/FluidVariant;Lnet/minecraft/world/BlockRenderView;Lnet/minecraft/util/math/BlockPos;)I", at = @At(value = "RETURN", ordinal = 1))
    private int getColor(int original, @Local(argsOnly = true) FluidVariant variant) {
        if (original != -1) {
            return original;
        }
        class_3611 fluid = variant.getFluid();
        FluidConfig config = AllFluidConfigs.get(fluid);
        if (config != null) {
            return config.tint().apply(variant.getComponents());
        }
        return -1;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/mixin/FluidVariantRenderHandlerMixin.java <==
package com.zurrtum.create.client.mixin;

import com.llamalad7.mixinextras.injector.ModifyReturnValue;
import com.llamalad7.mixinextras.sugar.Local;
import com.zurrtum.create.client.AllFluidConfigs;
import com.zurrtum.create.client.infrastructure.fluid.FluidConfig;
import net.fabricmc.fabric.api.transfer.v1.client.fluid.FluidVariantRenderHandler;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidVariant;
import net.minecraft.class_1058;
import net.minecraft.class_3611;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(FluidVariantRenderHandler.class)
public interface FluidVariantRenderHandlerMixin {
    @ModifyReturnValue(method = "getSprites(Lnet/fabricmc/fabric/api/transfer/v1/fluid/FluidVariant;)[Lnet/minecraft/client/renderer/texture/TextureAtlasSprite;", at = @At(value = "RETURN", ordinal = 1))
    private class_1058[] getSprites(class_1058[] original, @Local(argsOnly = true) FluidVariant variant) {
        if (original != null) {
            return original;
        }
        class_3611 fluid = variant.getFluid();
        FluidConfig config = AllFluidConfigs.get(fluid);
        if (config != null) {
            return new class_1058[]{config.still().get(), config.flowing().get()};
        }
        return null;
    }

    @ModifyReturnValue(method = "getColor(Lnet/fabricmc/fabric/api/transfer/v1/fluid/FluidVariant;Lnet/minecraft/world/level/BlockAndTintGetter;Lnet/minecraft/core/BlockPos;)I", at = @At(value = "RETURN", ordinal = 1))
    private int getColor(int original, @Local(argsOnly = true) FluidVariant variant) {
        if (original != -1) {
            return original;
        }
        class_3611 fluid = variant.getFluid();
        FluidConfig config = AllFluidConfigs.get(fluid);
        if (config != null) {
            return config.tint().apply(variant.getComponents());
        }
        return -1;
    }
}
